@@ -20,7 +20,7 @@
 #' \dontrun{
 #' update_station_list()
 #' }
-#' @return \code{\link[data.table]{data.table}} object of station metadata.
+#'
 #' @author Adam H Sparks, \email{adamhsparks@gmail.com}
 #' @export
 #'
@@ -68,7 +68,6 @@ update_station_list <- function() {
   new_isd_history <- new_isd_history[!is.na(new_isd_history$LON), ]
 
   # left join the old and new data
-
   isd_history <- dplyr::left_join(
     old_isd_history,
     new_isd_history,
@@ -88,8 +87,6 @@ update_station_list <- function() {
     )
   )
 
-  isd_history <- data.table::setDT(isd_history)
-
   # overwrite the existing isd_history.rda file on disk
   fname <- system.file("extdata", "isd_history.rda", package = "GSODR")
   save(isd_history, file = fname, compress = "bzip2")
